@@ -28,7 +28,7 @@ import os
 import tokenize
 
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 
 try:
@@ -38,6 +38,14 @@ except NameError:
 
 
 def format_code(source, preferred_quote="'"):
+    """Return source code with quotes unified."""
+    try:
+        return _format_code(source, preferred_quote)
+    except (tokenize.TokenError, IndentationError):
+        return source
+
+
+def _format_code(source, preferred_quote):
     """Return source code with quotes unified."""
     if not source:
         return source
